@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2020 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2015 Richard Hughes <richard@hughsie.com>
  *
  * SPDX-License-Identifier: LGPL-2.1+
  */
@@ -38,6 +38,9 @@ void		 fwupd_device_set_id			(FwupdDevice	*device,
 const gchar	*fwupd_device_get_parent_id		(FwupdDevice	*device);
 void		 fwupd_device_set_parent_id		(FwupdDevice	*device,
 							 const gchar	*parent_id);
+const gchar	*fwupd_device_get_composite_id		(FwupdDevice	*device);
+void		 fwupd_device_set_composite_id		(FwupdDevice	*device,
+							 const gchar	*composite_id);
 FwupdDevice	*fwupd_device_get_parent		(FwupdDevice	*device);
 void		 fwupd_device_set_parent		(FwupdDevice	*device,
 							 FwupdDevice	*parent);
@@ -107,15 +110,29 @@ void		 fwupd_device_add_checksum		(FwupdDevice	*device,
 const gchar	*fwupd_device_get_plugin		(FwupdDevice	*device);
 void		 fwupd_device_set_plugin		(FwupdDevice	*device,
 							 const gchar	*plugin);
+G_DEPRECATED_FOR(fwupd_device_get_protocols)
 const gchar	*fwupd_device_get_protocol		(FwupdDevice	*device);
+G_DEPRECATED_FOR(fwupd_device_add_protocol)
 void		 fwupd_device_set_protocol		(FwupdDevice	*device,
 							 const gchar	*protocol);
+void		 fwupd_device_add_protocol		(FwupdDevice	*device,
+							 const gchar	*protocol);
+gboolean	 fwupd_device_has_protocol		(FwupdDevice	*device,
+							 const gchar	*protocol);
+GPtrArray	*fwupd_device_get_protocols		(FwupdDevice	*device);
 const gchar	*fwupd_device_get_vendor		(FwupdDevice	*device);
 void		 fwupd_device_set_vendor		(FwupdDevice	*device,
 							 const gchar	*vendor);
+G_DEPRECATED_FOR(fwupd_device_get_vendor_ids)
 const gchar	*fwupd_device_get_vendor_id		(FwupdDevice	*device);
+G_DEPRECATED_FOR(fwupd_device_add_vendor_id)
 void		 fwupd_device_set_vendor_id		(FwupdDevice	*device,
 							 const gchar	*vendor_id);
+void		 fwupd_device_add_vendor_id		(FwupdDevice	*device,
+							 const gchar	*vendor_id);
+gboolean	 fwupd_device_has_vendor_id		(FwupdDevice	*device,
+							 const gchar	*vendor_id);
+GPtrArray	*fwupd_device_get_vendor_ids		(FwupdDevice	*device);
 void		 fwupd_device_add_guid			(FwupdDevice	*device,
 							 const gchar	*guid);
 gboolean	 fwupd_device_has_guid			(FwupdDevice	*device,
